$.jqplot.Dragable

Plugin to make plotted points dragable by the user.

Summary

$.jqplot.Dragable | Plugin to make plotted points dragable by the user.
Properties |
color | CSS color spec for the dragged point (and adjacent line segment or bar).
constrainTo | Constrain dragging motion to an axis or to none.

### Properties

### color

> this.color

CSS color spec for the dragged point (and adjacent line segment or bar).

### constrainTo

> this.constrainTo = 'none'

Constrain dragging motion to an axis or to none. Allowable values are ‘none’, ‘x’, ‘y’

> this.color

CSS color spec for the dragged point (and adjacent line segment or bar).

> this.constrainTo = 'none'

Constrain dragging motion to an axis or to none.
Close